import scrapy, re
from datetime import datetime, date, timedelta

"""
Esta version descarga ingresando una fecha.
USO:

scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=2 -a day=21

No es recomendable para fechas de mas de un mes de antiguas.
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"

	def start_requests(self):
		section_list = ['baja-california', 'chihuahua', 'mexico', 'mundo',
										'cultura', 'espectaculos', 'deportes']

		year = getattr(self, 'year', None)
		month = getattr(self, 'month', None)
		day = getattr(self, 'day', None)
		self.baseURL = 'http://jornadabc.mx/'
		self.date = date(int(year), int(month), int(day))
		self.pages = 100

		for s in section_list:
			yield scrapy.Request(url=self.baseURL+'seccion/'+s, callback=self.parse_pagination)


	def parse_pagination(self, response):
		pagination = response.xpath('//li[@class="pager-last odd last"]/a/@href').extract()
		if len(pagination) > 0:
			p = 1

			while p <= self.pages:	
				if p == 1:
					yield scrapy.Request(url=response.url, callback=self.parse_link, dont_filter=True)
				elif p > 1:
					yield scrapy.Request(url=response.url+'?page='+str(p+1), callback=self.parse_link)

				p += 1
					

		else:
			yield scrapy.Request(url=response.url, callback=self.parse_link, dont_filter=True)


	def parse_link(self, response):
		section = response.url[response.url.rfind('/')+1:]
		if section == 'espectaculos' or section == 'deportes':
			path = '//*[@class="region region-soft-first"]'
		else:
			path = '//*[@class="region region-hard-first"]'

		link_list = response.xpath(path).css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract()
		if len(link_list) > 0:
			for link in link_list:
				news_date = datetime.strptime(link[:link.rfind('/')][link[:link.rfind('/')].rfind('/')+1:], '%d-%m-%Y').date()
				
				if news_date == self.date:
					yield scrapy.Request(url=self.baseURL+link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''

		## la fecha de la noticia ya incluye la zona horaria
		item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()

		title = response.xpath('//*[@class="block-content"]/h1/a/text()').extract()
		if len(title) > 0:
			item['title'] = title[0]
		else:
			item['title'] = response.xpath('//*[@class="block-content"]/h1/text()').extract_first()

		item['topic'] = response.xpath('//span[@class="section"]/text()').extract_first()
		for paragraph in response.xpath('//*[@class="field-item even"]/p/text()').extract():
			text += paragraph
		item['text'] = text
		item['url'] = response.url
		
		# print item['title']
		yield item
