import scrapy, re

"""
Esta version descarga todas las noticias contenidas en la pagina, sin necesidad
de una fecha especifica.
USO:

scrapy crawl noticias -t json --nolog -o noticias.json

Genera un archivo JSON con todas las noticias disponibles. El archivo 'parse_date_file.py'
puede servir para clasificar dichas noticias en sus respectivas fechas.
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = 'noticias'
	
	def start_requests(self):
		self.baseURL = 'http://jornadabc.mx'
		section_list = ['baja-california', 'chihuahua', 'mexico', 'mundo',
										'cultura', 'espectaculos', 'deportes']
		
		for section in section_list:
			yield scrapy.Request(url=self.baseURL+'/seccion/'+section, callback=self.parse)


	def parse(self, response):
		pagination = response.xpath('//ul[@class="pager"]/li[@class="pager-last odd last"]/a/@href').extract()
		if ( len(pagination) > 0 ):
			section = response.url[response.url.rfind('/')+1:]
			pagination = pagination[0]
			pages = int(pagination[pagination.rfind('=')+1:])
			
			for page in range(0, pages):
				if ( page == 0 ):
					yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
				else:
					yield scrapy.Request(url=self.baseURL+'/seccion/'+section+'?page='+str(page), callback=self.parse_page, dont_filter=True)
		
		else:
			yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)


	def parse_page(self, response):
		section = response.url[response.url.rfind('/')+1:]
		section = section[:section.rfind('?')]
		if ( section == 'espectaculos' or section == 'deportes' ):
			link_list = response.xpath('//*[@class="region region-soft-first"]').css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract()
		else:
			link_list = response.xpath('//*[@class="region region-hard-first"]').css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract()

			if len(link_list) <= 0:
				link_list = response.xpath('//*[@class="view-content"]').css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract()

		for link in link_list:
			yield scrapy.Request(url=self.baseURL+link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		
		## la fecha de las noticias ya incluye la zona horaria
		item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
		title = response.xpath('//*[@class="block-content"]/h1/a/text()').extract()
		if ( len(title) > 0 ):
			item['title'] = title[0]
		else:
			item['title'] = response.xpath('//*[@class="block-content"]/h1/text()').extract_first()

		item['topic'] = response.xpath('//span[@class="section"]/text()').extract_first()
		for paragraph in response.xpath('//*[@class="field-item even"]/p/text()').extract():
			text += paragraph
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item
